@@ -124,8 +124,9 @@ class DipSendDiv < Div::Div
   
   def do_send(context, params)
     return unless server
-    msg, = params['message']
+    msg = params['message']
     return unless msg
+    msg = msg.join('')
     return if msg == ''
     server.send_msg(@addr, msg, true)
     @addr = nil
@@ -197,6 +198,24 @@ class DipMsgDiv < Div::Div
   end
 end
 
+class DipBiff < Div::Div
+  set_erb('biff.erb')
+  
+  def initialize(session, dip)
+    super(session)
+    @dip = dip
+  end
+
+  def server
+    @dip.server
+  end
+  
+  def has_unopened?
+    return false unless @dip.server
+    return server.msg_holder.has_unopened?
+  end
+end
+
 class BaseDiv < Div::Div
   set_erb('base.erb')
 
@@ -204,18 +223,26 @@ class BaseDiv < Div::Div
     super(session)
     @dip = DipDiv.new(session)
   end
+  attr_reader :dip
 end
 
 class DipTofuSession < Div::TofuSession
   def initialize(bartender, hint=nil)
     super(bartender, hint)
     @base = BaseDiv.new(self)
+    @biff = DipBiff.new(self, @base.dip)
   end
 
   def do_GET(context)
     update_div(context)
     context.res_header('content-type', 'text/html; charset=euc-jp')
-    context.res_body(@base.to_html(context))
+    p context.req_path_info
+    case context.req_path_info
+    when '/biff'
+      context.res_body(@biff.to_html(context))
+    else
+      context.res_body(@base.to_html(context))
+    end
   end
 end
 
