@@ -14,7 +14,7 @@ class SimpleObserver
   end
   
   def do_recv(msg)
-    puts kconv(">>>>>>>>>>>> From: #{msg.from[3]}")
+    puts kconv(">>>>>>>>>>>> From: #{msg.from.addr}")
     puts kconv(msg.message)
     puts "-------------------------------------------------"
   end
